<?php
/**
*
* ucp.php [Lithuanian]
*
* @package language
* @version $Id: $
* @copyright (c) 2012 phpBB Group
* @author 2012-01-04 - Vilius Šumskas
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

/**
* DO NOT CHANGE
*/
if (!defined('IN_PHPBB'))
{
	exit;
}

if (empty($lang) || !is_array($lang))
{
	$lang = array();
}

// DEVELOPERS PLEASE NOTE
//
// All language files should use UTF-8 as their encoding and the files must not contain a BOM.
//
// Placeholders can now contain order information, e.g. instead of
// 'Page %s of %s' you can (and should) write 'Page %1$s of %2$s', this allows
// translators to re-order the output of data while ensuring it remains correct
//
// You do not need this where single placeholders are used, e.g. 'Message %d' is fine
// equally where a string contains only two placeholders which are used to wrap text
// in a url you again do not need to specify an order e.g., 'Click %sHERE%s' is fine

$lang = array_merge($lang, array(
	'TERMS_OF_USE_CONTENT'	=> 'Prisijungdami prie “%1$s” (toliau “mes”, “mūsų”, “%1$s”, “%2$s”), jūs pasižadate laikytis šių taisyklių. Jeigu nesutinkate laikytis visų šių taisyklių, nesiregistruokite ir/arba nenaudokite “%1$s”. Bet kuriuo metu mes galima pakeisti taisykles ir padarysime viską, kad jūs būtumėte apie tai informuotas, tačiau, kadangi ir toliau naudosite “%1$s” po pakeitimų, yra protinga reguliariai patikrinti šias taisykles patiems.<br />
	<br />
	Mūsų diskusijos naudoja phpBB programinę įrangą (toliau “jie”, “jų”, “phpBB programinė įranga”, “www.phpbb.com”, “phpBB Grupė”, “phpBB Komanda”) išleistą po “<a href="http://opensource.org/licenses/gpl-license.php">Bendroji Vieša Licencija (GPL)</a>” (toliau “GPL”). Ją galima atsisiųsti iš <a href="http://www.phpbb.com/">www.phpbb.com</a> puslapio. phpBB programinė įranga tik palengvina Internetinį bendravimą, o GPL licencija užtikrina, kad jie neturi nieko bendro su tuo, ką mes leidžiame ir ko neleidžiame diskusijose. Daugiau informacijos apie phpBB galite rasti: <a href="http://www.phpbb.com/">http://www.phpbb.com/</a>.<br />
	<br />
	Jūs sutinkate nerašyti įžeidžiančių, nešvankių, vulgarių, šmeižiančių, grasinančių ir kitokių vietinius įstatymus, šalies kur talpinama “%1$s” arba Tarptautinius Įstatymus pažeidžiančių žinučių. Priešingu atveju tuojau pat būsite blokuotas (banned) ir apie tai bus pranešta jūsų Interneto paslaugų teikėjui. Visų žinučių IP adresas yra įrašomas į duomenų bazę. Jūs sutinkate, kad “%1$s” turi teisę ištrinti, redaguoti, perkelti arba uždaryti bet kurią temą/žinutę bet kuriuo metu jeigu jie mano jog tai reikalinga. Kaip vartotojas sutinkate su tuo, kad bet kokia jūsų įvesta informacija būtų saugoma duomenų bazėje. Ši informacija nebus teikiama jokioms trečioms šalims be jūsų sutikimo, tačiau nei “%1$s”, nei phpBB įsilaužimo atveju neprisiima atsakomybės dėl informacijos saugumo.
	',
	'PRIVACY_POLICY'	=> 'Ši privatumo politika detaliai apibūdina kaip “%1$s” kartu su jai atstovaujančioms kompanijoms (toliau “mes”, “mūsų”, “%1$s”, “%2$s”) bei phpBB (toliau “jie”, “jų”, “phpBB programinė įranga”, “www.phpbb.com”, “phpBB Grupė”, “phpBB Komanda”) naudoja bet kurios sesijos metu surinktą informaciją (toliau “jūsų informacija”).<br />
	<br />
	Informacija renkama dviem būdais. Pirmiausia, naršant po  phpBB programinė įranga sukuria keletą sausainėlių. Sausainėliai - tai maži tekstiniai failai, kurie atsiunčiami į jūsų kompiuterio naršyklės laikinų failų katalogą. Pirmuose dvejuose sausainėliuose yra vartotojo identifikavimo informacija (toliau “vartotojo id”) bei anoniminė sesijos informacija (toliau “sesijos id”). Šie du parametrai jums priskiriami automatiškai kiekvieno phpBB programinės įrangos naudojimosi metu. Trečiasis sausainėlis bus sukurtas tada, kai perskaitysite bent vieną “%1$s” temą. Šis parametras nurodo, kurias temas jūs jau perskaitėte, taip suteikdamas patogesnį dalyvavimą diskusijose.<br />
	<br />
	Taip pat, naršant “%1$s”, mes galime sukurti papildomus sausainėlius, tačiau jie neaprašomi šiame dokumente, kadangi jis skirtas tik phpBB programinei įrangai. Kitas būdas, kuriuo mes renkame informaciją, yra kai jūs siunčiate informaciją patys. Tai gali būti, bet nesudaro: pranešimų rašymas anoniminio vartotojo vardu (toliau “anoniminiai pranešimai”), registracija “%1$s” (toliau “jūsų prisijungimo duomenys”) ir pranešimų rašymas prisijungus registruotu vardu (toliau “jūsų pranešimai”).<br />
	<br />
	Jūsų prisijungimo duomenys bus sudaryti bent iš unikalaus vartotojo vardo (toliau “jūsų vartotojo vardas”), asmeninio slaptažodžio skirto prisijungti prie diskusijų (toliau “jūsų slaptažodis”) ir asmeninio tikro el. pašto adreso (toliau “jūsų el. pašto adresas”). Informacija, susijusi su šiais duomenimis, yra saugoma šalies, kurioje talpinamas “%1$s”, įstatymų. Dėl visų kitų duomenų, kurie gali būti surinkti registracijos prie “%1$s” metu, mes sprendžiame patys. Bet kuriuo atveju, jūs galite pasirinkti, kuriuos duomenis rodyti viešai, o kuriuos slėpti. Taipogi, savo aprašyme jūs turite galimybę pasirinkti, ar gauti automatiškai sugeneruotus el. laiškus nuo phpBB programinės įrangos, ar ne.<br />
	<br />
	Jūsų slaptažodis yra užkoduotas (vienpusio kodavimo būdu) ir yra saugus. Tačiau nerekomenduojama naudoti to paties slaptažodžio, kurį naudojate kituose Interneto puslapiuose. Jūsų slaptažodis skirtas tik prisijungimui prie “%1$s”, todėl akylai jį saugokite ir jokiu būdu neteikite jo nei “%1$s” atstovams, nei phpBB, nei bet kurioms trečioms šalims. Mes niekada neprašome jūsų slaptažodžio. Pamirštą slaptažodį bet kada galite pasikeisti pasinaudoję “Aš pamiršau savo slaptažodį” nuoroda. Šio proceso metu jūs būsite paprašytas įvesti savo vartotojo vardą ir el. pašto adresą, ir phpBB programinė įranga sugeneruos naują prisijungimo slaptažodį.<br />
	',
	'ACCOUNT_ACTIVE'	=> 'Jūsų vartotojo vardas aktyvuotas. Ačiū, kad užsiregistravote.',
	'ACCOUNT_ACTIVE_ADMIN'	=> 'Vartotojo vardas aktyvuotas.',
	'ACCOUNT_ACTIVE_PROFILE'	=> 'Jūsų vartotojo vardas buvo sėkmingai aktyvuotas dar kartą.',
	'ACCOUNT_ADDED'	=> 'Ačiū, kad užsiregistravote. Jūsų vartotojo vardas sukurtas. Dabar galite prisijungti su savo vartotojo vardu ir slaptažodžiu.',
	'ACCOUNT_COPPA'	=> 'Jūsų vartotojo vardas sukurtas, tačiau dar nepatvirtintas. El. paštu turite gauti tolesnius nurodymus.',
	'ACCOUNT_EMAIL_CHANGED'	=> 'Jūsų prisijungimo duomenys atnaujinti. Tačiau, pakeitus el. pašto adresą, reikia dar kartą aktyvuoti savo vartotojo vardą. Aktyvavimo raktas buvo išsiųstas nauju el. paštu, kurį nurodėte. Prašome patikrinti savo el. pašto dėžutę.',
	'ACCOUNT_EMAIL_CHANGED_ADMIN'	=> 'Jūsų prisijungimo duomenys atnaujinti. Tačiau, pakeitus el. pašto adresą, jūsų vartotojo vardą turi dar kartą aktyvuoti administratorius. El. laiškas jiems jau išsiųstas. Jūs būsite informuotas, kai jūsų vartotojo vardas bus vėl aktyvuotas.',
	'ACCOUNT_INACTIVE'	=> 'Jūsų vartotojo vardas sukurtas, tačiau jį dar reikia aktyvuoti. Aktyvavimo raktas buvo išsiųstas el. pašto adresu, kurį nurodėte. Prašome patikrinti savo el. pašto dėžutę.',
	'ACCOUNT_INACTIVE_ADMIN'	=> 'Jūsų vartotojo vardas sukurtas, tačiau jį dar turi patvirtinti administratorius. El. laiškas jiems jau išsiųstas. Jūs būsite informuotas, kai jūsų vartotojo vardas bus aktyvuotas.',
	'ACTIVATION_EMAIL_SENT'	=> 'Aktyvavimo raktas išsiųstas el. pašto adresu, kurį nurodėte.',
	'ACTIVATION_EMAIL_SENT_ADMIN'	=> 'Aktyvavimo raktas el. paštu išsiųstas administratoriui.',
	'ADD'	=> 'Pridėti',
	'ADD_BCC'	=> 'Pridėti [BCC]',
	'ADD_FOES'	=> 'Įtraukti naujus priešus',
	'ADD_FOES_EXPLAIN'	=> 'Galite įtraukti daugiau nei vieną vartotojo vardą parašę juos skirtingose eilutėse.',
	'ADD_FOLDER'	=> 'Sukurti katalogą',
	'ADD_FRIENDS'	=> 'Įtraukti naujus draugus',
	'ADD_FRIENDS_EXPLAIN'	=> 'Galite įtraukti daugiau nei vieną vartotojo vardą parašę juos skirtingose eilutėse.',
	'ADD_NEW_RULE'	=> 'Sukurti naują taisyklę',
	'ADD_RULE'	=> 'Sukurti taisyklę',
	'ADD_TO'	=> 'Pridėti [Kam]',
	'ADD_USERS_UCP_EXPLAIN'	=> 'Čia į grupę galite įtraukti naujus narius. Galite pasirinkti, ar ši grupė taps pagrindine nurodytiems vartotojams. Kiekvieną vartotojo vardą nurodykite naujoje eilutėje.',
	'ADMIN_EMAIL'	=> 'Administratoriai gali siųsti man el. laiškus',
	'AGREE'	=> 'Aš sutinku su šiomis sąlygomis',
	'ALLOW_PM'	=> 'Leisti kitiems vartotojams siųsti jums asmenines žinutes',
	'ALLOW_PM_EXPLAIN'	=> 'Administratoriai ir moderatoriai visada galės siųsti jums žinutes.',
	'ALREADY_ACTIVATED'	=> 'Jūs jau aktyvavote savo vartotojo vardą.',
	'ATTACHMENTS_EXPLAIN'	=> 'Failų, kuriuos prikabinote prie savo parašytų pranešimų, sąrašas.',
	'ATTACHMENTS_DELETED'	=> 'Prikabinti failai sėkmingai ištrinti.',
	'ATTACHMENT_DELETED'	=> 'Prikabintas failas sėkmingai ištrintas.',
	'AVATAR_CATEGORY'	=> 'Kategorija',
	'AVATAR_EXPLAIN'	=> 'Maksimalūs dydžiai; plotis: %1$d pikseliai, aukštis: %2$d pikseliai, failo dydis: %3$.2f KiB.',
	'AVATAR_FEATURES_DISABLED'	=> 'Avatarų galerija išjungta.',
	'AVATAR_GALLERY'	=> 'Vietinė galerija',
	'AVATAR_GENERAL_UPLOAD_ERROR'	=> 'Nepavyko nusiųsti avataro į %s.',
	'AVATAR_NOT_ALLOWED'	=> 'Jūsų avataras nerodomas, nes avatarai buvo uždrausti.',
	'AVATAR_PAGE'	=> 'Puslapis',
	'AVATAR_TYPE_NOT_ALLOWED'	=> 'Jūsų dabartinis avataras nerodomas, nes šis avatarų tipas buvo uždraustas.',
	'BACK_TO_DRAFTS'	=> 'Atgal į išsaugotų juodraščių sąrašą',
	'BACK_TO_LOGIN'	=> 'Atgal į prisijungimo langą',
	'BIRTHDAY'	=> 'Gimtadienis',
	'BIRTHDAY_EXPLAIN'	=> 'Jūsų gimtadienio metu bus rodomas jūsų amžius.',
	'BOARD_DATE_FORMAT'	=> 'Mano datos formatas',
	'BOARD_DATE_FORMAT_EXPLAIN'	=> 'Naudojama sintaksė identiška PHP funkcijos <a href="http://www.php.net/date">date()</a> sintaksei.',
	'BOARD_DST'	=> 'Ar šiuo metu naudojamas vasaros laikas',
	'BOARD_LANGUAGE'	=> 'Mano kalba',
	'BOARD_STYLE'	=> 'Mano diskusijų lentos stilius',
	'BOARD_TIMEZONE'	=> 'Mano laiko juosta',
	'BOOKMARKS'	=> 'Žymės',
	'BOOKMARKS_EXPLAIN'	=> 'Jūs galite pasižymėti tam tikras temas. Jeigu norite ištrinti temą iš šio sąrašo, pažymėkite ją ir paspauskite <em>Pašalinti žymes</em> mygtuką.',
	'BOOKMARKS_DISABLED'	=> 'Žymės išjungtos.',
	'BOOKMARKS_REMOVED'	=> 'Žymės sėkmingai pašalintos.',
	'CANNOT_EDIT_MESSAGE_TIME'	=> 'Jūs nebegalite redaguoti arba ištrinti šios žinutės.',
	'CANNOT_MOVE_TO_SAME_FOLDER'	=> 'Jūs negalite perkelti žinučių į katalogą, kuriame jos yra.',
	'CANNOT_MOVE_FROM_SPECIAL'	=> 'Perkelti žinučių iš siunčiamų katalogo negalima.',
	'CANNOT_RENAME_FOLDER'	=> 'Pervadinti katalogo negalima.',
	'CANNOT_REMOVE_FOLDER'	=> 'Ištrinti katalogo negalima.',
	'CHANGE_DEFAULT_GROUP'	=> 'Pakeisti pagrindinę grupę',
	'CHANGE_PASSWORD'	=> 'Pakeisti slaptažodį',
	'CLICK_GOTO_FOLDER'	=> '%1$sEiti į “%3$s” katalogą%2$s',
	'CLICK_RETURN_FOLDER'	=> '%1$sGrįžti į “%3$s” katalogą%2$s',
	'CONFIRMATION'	=> 'Registracijos patvirtinimas',
	'CONFIRM_CHANGES'	=> 'Patvirtinti pakeitimus',
	'CONFIRM_EMAIL'	=> 'El. pašto adreso patvirtinimas',
	'CONFIRM_EMAIL_EXPLAIN'	=> 'Įrašykite tik jeigu keičiate savo el. pašto adresą.',
	'CONFIRM_EXPLAIN'	=> 'Patvirtinimo kodas skirtas apsaugai nuo automatinių registracijų. Patį kodą turite matyti paveikslėlyje apačioje. Jeigu blogai matote, arba dėl kokių nors kitų priežasčių negalite jo perskaityti, kreipkitės į %sdiskusijų administratorių%s.',
	'VC_REFRESH'	=> 'Atnaujinti patvirtinimo kodą',
	'VC_REFRESH_EXPLAIN'	=> 'Jeigu negalite perskaityti kodo, galite paprašyti naujo paspaudę mygtuką.',
	'CONFIRM_PASSWORD'	=> 'Slaptažodžio patvirtinimas',
	'CONFIRM_PASSWORD_EXPLAIN'	=> 'Įrašykite tik jeigu pakeitėte savo slaptažodį viršuje.',
	'COPPA_BIRTHDAY'	=> 'Norėdami tęsti registraciją, turite nurodyti savo gimimo datą.',
	'COPPA_COMPLIANCE'	=> 'COPPA sutikimas',
	'COPPA_EXPLAIN'	=> 'Paspaudę mygtuką apačioje sukursite savo vartotojo vardą. Tačiau jis nebus aktyvuotas, kol jūsų tėvai arba globėjai nepatvirtins jūsų registracijos. El. paštu gausite formą kurią reikia užpildyti ir informaciją kur ją reikia išsiųsti.',
	'CREATE_FOLDER'	=> 'Sukurti katalogą…',
	'CURRENT_IMAGE'	=> 'Dabartinis paveikslėlis',
	'CURRENT_PASSWORD'	=> 'Dabartinis slaptažodis',
	'CURRENT_PASSWORD_EXPLAIN'	=> 'Jeigu norite pakeisti savo slaptažodį, vartotojo vardą, arba el. pašto adresą, turite įrašyti dabartinį slaptažodį.',
	'CUR_PASSWORD_EMPTY'	=> 'Jūs neįrašėte dabartinio slaptažodžio.',
	'CUR_PASSWORD_ERROR'	=> 'Slaptažodis, kurį įrašėte, yra neteisingas.',
	'CUSTOM_DATEFORMAT'	=> 'Individualus…',
	'DEFAULT_ACTION'	=> 'Standartinis veiksmas',
	'DEFAULT_ACTION_EXPLAIN'	=> 'Šis veiksmas bus vykdomas tuo atveju, jeigu neatitiks nei viena sąlyga nurodyta aukščiau.',
	'DEFAULT_ADD_SIG'	=> 'Visada pridėti mano parašą',
	'DEFAULT_BBCODE'	=> 'Visada įjungti BBKodą',
	'DEFAULT_NOTIFY'	=> 'Visada perspėti mane apie atsakymus',
	'DEFAULT_SMILIES'	=> 'Visada įjungti šypsenėles',
	'DEFINED_RULES'	=> 'Aprašytos taisyklės',
	'DELETED_TOPIC'	=> 'Tema ištrinta.',
	'DELETE_ATTACHMENT'	=> 'Ištrinti prikabintą failą',
	'DELETE_ATTACHMENTS'	=> 'Ištrinti prikabintus failus',
	'DELETE_ATTACHMENT_CONFIRM'	=> 'Ar tikrai norite ištrinti šį prikabintą failą?',
	'DELETE_ATTACHMENTS_CONFIRM'	=> 'Ar tikrai norite ištrinti šiuos prikabintus failus?',
	'DELETE_AVATAR'	=> 'Ištrinti paveikslėlį',
	'DELETE_COOKIES_CONFIRM'	=> 'Ar tikrai norite ištrinti visus šios diskusijų lentos sukurtus sausainėlius?',
	'DELETE_MARKED_PM'	=> 'Ištrinti pažymėtas žinutes',
	'DELETE_MARKED_PM_CONFIRM'	=> 'Ar tikrai norite ištrinti visas pažymėtas žinutes?',
	'DELETE_OLDEST_MESSAGES'	=> 'Ištrinti seniausias žinutes',
	'DELETE_MESSAGE'	=> 'Ištrinti žinutę',
	'DELETE_MESSAGE_CONFIRM'	=> 'Ar tikrai norite ištrinti šią asmeninę žinutę?',
	'DELETE_MESSAGES_IN_FOLDER'	=> 'Ištrinti visas žinutes pašalintame kataloge',
	'DELETE_RULE'	=> 'Ištrinti taisyklę',
	'DELETE_RULE_CONFIRM'	=> 'Ar tikrai norite ištrinti šią taisyklę?',
	'DEMOTE_SELECTED'	=> 'Pažeminti pareigose',
	'DISABLE_CENSORS'	=> 'Įjungti cenzūrą',
	'DISPLAY_GALLERY'	=> 'Rodyti galeriją',
	'DOMAIN_NO_MX_RECORD_EMAIL'	=> 'Įrašyto el. pašto domenas neturi MX įrašo.',
	'DOWNLOADS'	=> 'Atsisiuntimai',
	'DRAFTS_DELETED'	=> 'Visi pažymėti juodraščiai sėkmingai ištrinti.',
	'DRAFTS_EXPLAIN'	=> 'Čia galite peržiūrėti, redaguoti ir trinti išsaugotus juodraščius.',
	'DRAFT_UPDATED'	=> 'Juodraštis sėkmingai atnaujintas.',
	'EDIT_DRAFT_EXPLAIN'	=> 'Čia galite redaguoti savo juodraščius. Juodraščiuose nesaugomi prikabinti failai ar apklausos duomenys.',
	'EMAIL_BANNED_EMAIL'	=> 'El. pašto adresas, kurį įrašėte, yra uždraustas.',
	'EMAIL_INVALID_EMAIL'	=> 'El. pašto adresas, kurį įrašėte, yra neteisingas.',
	'EMAIL_REMIND'	=> 'El. pašto adresas susietas su jūsų vartotojo vardu. Jeigu nekeitėte jo per vartotojo valdymo pultą, tai bus tas pats el. pašto adresas, kurį naudojote registruodamiesi diskusijose.',
	'EMAIL_TAKEN_EMAIL'	=> 'Vartotojas su nurodytu el. pašto adresu jau užregistruotas.',
	'EMPTY_DRAFT'	=> 'Turite įrašyti juodraščio turinį.',
	'EMPTY_DRAFT_TITLE'	=> 'Turite įrašyti juodraščio pavadinimą.',
	'EXPORT_AS_XML'	=> 'Atsisiųsti kaip XML',
	'EXPORT_AS_CSV'	=> 'Atsisiųsti kaip CSV',
	'EXPORT_AS_CSV_EXCEL'	=> 'Atsisiųsti kaip CSV (Excel formatas)',
	'EXPORT_AS_TXT'	=> 'Atsisiųsti kaip TXT',
	'EXPORT_AS_MSG'	=> 'Atsisiųsti kaip MSG',
	'EXPORT_FOLDER'	=> 'Atsisiųsti katalogą',
	'FIELD_REQUIRED'	=> 'Laukelis “%s” turi būti užpildytas.',
	'FIELD_TOO_SHORT'	=> 'Laukelis “%1$s” per trumpas. Reikia bent %2$d simbolių.',
	'FIELD_TOO_LONG'	=> 'Laukelis “%1$s” per ilgas. Leidžiama ne daugiau kaip %2$d simbolių.',
	'FIELD_TOO_SMALL'	=> 'Laukelio “%1$s” reikšmė yra per maža. Mažiausia galima reikšmė - %2$d.',
	'FIELD_TOO_LARGE'	=> 'Laukelio “%1$s” reikšmė yra per didelė. Didžiausia galima reikšmė - %2$d.',
	'FIELD_INVALID_CHARS_NUMBERS_ONLY'	=> 'Laukelyje “%s” yra neleistinų simbolių. Jame galima rašyti tik skaičius.',
	'FIELD_INVALID_CHARS_ALPHA_ONLY'	=> 'Laukelyje “%s” yra neleistinų simbolių. Jame galima rašyti tik skaičius ir raides.',
	'FIELD_INVALID_CHARS_SPACERS_ONLY'	=> 'Laukelyje “%s” yra neleistinų simbolių. Jame galima rašyti tik skaičius, raides, tarpus arba simbolius -+_[].',
	'FIELD_INVALID_DATE'	=> 'Laukelyje “%s” įrašyta neteisinga data.',
	'FIELD_INVALID_VALUE'	=> 'Laukelyje “%s” įrašyta neteisinga reikšmė.',
	'FOE_MESSAGE'	=> 'Žinutė nuo priešo',
	'FOES_EXPLAIN'	=> 'Priešai yra vartotojai, kurie bus ignoruojami. Šių vartotojų pranešimai nebus rodomi. Asmeninės žinutės nuo priešų yra leidžiamos. Atsiminkite, kad tokiu būdu negalite ignoruoti moderatorių ar administratorių.',
	'FOES_UPDATED'	=> 'Jūsų priešų sąrašas sėkmingai atnaujintas.',
	'FOLDER_ADDED'	=> 'Katalogas sėkmingai sukurtas.',
	'FOLDER_MESSAGE_STATUS'	=> 'Saugoma %1$d iš %2$d žinučių',
	'FOLDER_NAME_EMPTY'	=> 'Įrašykite katalogo pavadinimą.',
	'FOLDER_NAME_EXIST'	=> 'Katalogas <strong>%s</strong> jau egzistuoja.',
	'FOLDER_OPTIONS'	=> 'Katalogo nustatymai',
	'FOLDER_RENAMED'	=> 'Katalogas sėkmingai pervadintas.',
	'FOLDER_REMOVED'	=> 'Katalogas sėkmingai ištrintas.',
	'FOLDER_STATUS_MSG'	=> 'Katalogas užimtas %1$d%% (saugoma %2$d iš %3$d žinučių)',
	'FORWARD_PM'	=> 'Persiųsti AŽ',
	'FORCE_PASSWORD_EXPLAIN'	=> 'Norėdami toliau naršyti diskusijose jūs turite pasikeisti savo slaptažodį.',
	'FRIEND_MESSAGE'	=> 'Žinutė nuo draugo',
	'FRIENDS'	=> 'Draugai',
	'FRIENDS_EXPLAIN'	=> 'Draugų sąrašas jums padeda greičiau bendrauti su dalyviais kurie jums artimi. Jeigu naudojamas šablonas palaiko šią galimybę, jūsų draugų pranešimai bus paryškinti.',
	'FRIENDS_OFFLINE'	=> 'Atsijungęs',
	'FRIENDS_ONLINE'	=> 'Prisijungęs',
	'FRIENDS_UPDATED'	=> 'Jūsų draugų sąrašas sėkmingai atnaujintas.',
	'FULL_FOLDER_OPTION_CHANGED'	=> 'Veiksmas, kai katalogas tampa pilnas, sėkmingai pakeistas.',
	'FWD_ORIGINAL_MESSAGE'	=> '-------- Pirminė žinutė --------',
	'FWD_SUBJECT'	=> 'Tema: %s',
	'FWD_DATE'	=> 'Data: %s',
	'FWD_FROM'	=> 'Nuo: %s',
	'FWD_TO'	=> 'Kam: %s',
	'GLOBAL_ANNOUNCEMENT'	=> 'Labai svarbus pranešimas',
	'HIDE_ONLINE'	=> 'Paslėpti mano būseną',
	'HIDE_ONLINE_EXPLAIN'	=> 'Šio nustatymo galiojimas pasireiškia tik nuo kito apsilankymo diskusijose.',
	'HOLD_NEW_MESSAGES'	=> 'Nebepriimti naujų žinučių (naujos žinutės stovės eilėje kol atsiras joms vietos)',
	'HOLD_NEW_MESSAGES_SHORT'	=> 'Naujos žinutės stovės eilėje',
	'IF_FOLDER_FULL'	=> 'Jeigu katalogas pilnas',
	'IMPORTANT_NEWS'	=> 'Labai svarbūs pranešimai',
	'INVALID_USER_BIRTHDAY'	=> 'Įrašyta neteisinga gimtadienio data.',
	'INVALID_CHARS_USERNAME'	=> 'Vartotojo varde yra draudžiamų simbolių.',
	'INVALID_CHARS_NEW_PASSWORD'	=> 'Slaptažodyje nėra visų būtinų simbolių.',
	'ITEMS_REQUIRED'	=> 'Punktai pažymėti * yra privalomi.',
	'JOIN_SELECTED'	=> 'Įstoti į pažymėtą',
	'LANGUAGE'	=> 'Kalba',
	'LINK_REMOTE_AVATAR'	=> 'Nutolęs avataro adresas',
	'LINK_REMOTE_AVATAR_EXPLAIN'	=> 'Įrašykite avataro, kurį norite susieti su savo aprašymu, URL adresą.',
	'LINK_REMOTE_SIZE'	=> 'Avataro dimensijos',
	'LINK_REMOTE_SIZE_EXPLAIN'	=> 'Nurodykite avataro plotį ir aukštį. Šį lauką galite palikti ir tuščią. Tokiu atveju sistema pati pabandys nustatyti avataro dimensijas.',
	'LOGIN_EXPLAIN_UCP'	=> 'Norėdami naudotis vartotojo valdymo pultu turite prisijungti.',
	'LOGIN_REDIRECT'	=> 'Jūs sėkmingai prisijungėte.',
	'LOGOUT_FAILED'	=> 'Jūs neatsijungėte, kadangi užklausa neatitiko jūsų sesijos. Jeigu ši problema pasikartos, susisiekite su diskusijų administratoriumi.',
	'LOGOUT_REDIRECT'	=> 'Jūs sėkmingai atsijungėte.',
	'MARK_IMPORTANT'	=> 'Pažymėti/Atžymėti kaip svarbią',
	'MARKED_MESSAGE'	=> 'Pažymėta žinutė',
	'MAX_FOLDER_REACHED'	=> 'Pasiekėte maksimalų leistiną katalogų kiekį.',
	'MESSAGE_BY_AUTHOR'	=> '',
	'MESSAGE_COLOURS'	=> 'Žinučių spalvos',
	'MESSAGE_DELETED'	=> 'Žinutė sėkmingai ištrinta.',
	'MESSAGE_HISTORY'	=> 'Žinutės istorija',
	'MESSAGE_REMOVED_FROM_OUTBOX'	=> 'Žinutę, prieš ją išsiunčiant, ištrynė pats autorius.',
	'MESSAGE_SENT_ON'	=> '',
	'MESSAGE_STORED'	=> 'Žinutė išsiųsta sėkmingai.',
	'MESSAGE_TO'	=> 'Kam',
	'MESSAGES_DELETED'	=> 'Žinutės sėkmingai ištrintos',
	'MOVE_DELETED_MESSAGES_TO'	=> 'Perkelti žinutes iš ištrinto katalogo į',
	'MOVE_DOWN'	=> 'Perkelti žemyn',
	'MOVE_MARKED_TO_FOLDER'	=> 'Perkelti pažymėtas žinutes į %s',
	'MOVE_PM_ERROR'	=> 'Keliant žinutes į naują katalogą įvyko klaida. Perkeltos tik %1d iš %2d žinučių.',
	'MOVE_TO_FOLDER'	=> 'Perkelti į katalogą',
	'MOVE_UP'	=> 'Perkelti aukštyn',
	'NEW_EMAIL_CONFIRM_EMPTY'	=> 'Jūs neįrašėte el. pašto adreso patvirtinimui.',
	'NEW_EMAIL_ERROR'	=> 'El. pašto adresai, kuriuos įrašėte, nesutampa.',
	'NEW_FOLDER_NAME'	=> 'Naujo katalogo pavadinimas',
	'NEW_PASSWORD'	=> 'Naujas slaptažodis',
	'NEW_PASSWORD_CONFIRM_EMPTY'	=> 'Jūs neįrašėte slaptažodžio patvirtinimui.',
	'NEW_PASSWORD_ERROR'	=> 'Slaptažodžiai, kuriuos įrašėte, nesutampa.',
	'NOTIFY_METHOD'	=> 'Informavimo būdas',
	'NOTIFY_METHOD_BOTH'	=> 'Abu',
	'NOTIFY_METHOD_EMAIL'	=> 'Tik el. paštu',
	'NOTIFY_METHOD_EXPLAIN'	=> 'Būdas kuriuo bus siunčiamos žinutės išsiųstos per diskusijų lentą.',
	'NOTIFY_METHOD_IM'	=> 'Tik per Jabber',
	'NOTIFY_ON_PM'	=> 'Perspėti apie naują asmeninę žinutę',
	'NOT_ADDED_FRIENDS_ANONYMOUS'	=> 'Jūs negalite įtraukti svečių į savo draugų sąrašą.',
	'NOT_ADDED_FRIENDS_BOTS'	=> 'Jūs negalite įtraukti robotų į savo draugų sąrašą.',
	'NOT_ADDED_FRIENDS_FOES'	=> 'Jūs negalite įtraukti į savo draugų sąrašą vartotojų, kurie jau yra jūsų priešų sąraše.',
	'NOT_ADDED_FRIENDS_SELF'	=> 'Jūs negalite įtraukti savęs į savo draugų sąrašą.',
	'NOT_ADDED_FOES_MOD_ADMIN'	=> 'Jūs negalite įtraukti administratorių ar moderatorių į savo priešų sąrašą.',
	'NOT_ADDED_FOES_ANONYMOUS'	=> 'Jūs negalite įtraukti svečių į savo priešų sąrašą.',
	'NOT_ADDED_FOES_BOTS'	=> 'Jūs negalite įtraukti robotų į savo priešų sąrašą.',
	'NOT_ADDED_FOES_FRIENDS'	=> 'Jūs negalite įtraukti į savo priešų sąrašą vartotojų, kurie jau yra jūsų draugų sąraše.',
	'NOT_ADDED_FOES_SELF'	=> 'Jūs negalite įtraukti savęs į savo priešų sąrašą.',
	'NOT_AGREE'	=> 'Aš nesutinku su šiomis sąlygomis',
	'NOT_ENOUGH_SPACE_FOLDER'	=> 'Katalogas “%s” yra pilnas. Pasirinkto veiksmo įvykdyti nepavyks.',
	'NOT_MOVED_MESSAGE'	=> 'Jūsų laukia 1 asmeninė žinutė, nes katalogas pilnas.',
	'NOT_MOVED_MESSAGES'	=> 'Jūsų laukia %d asmeninės žinutės, nes katalogas pilnas.',
	'NO_ACTION_MODE'	=> 'Nenurodytas žinutės veiksmas.',
	'NO_AUTHOR'	=> 'Nenurodytas žinutės autorius',
	'NO_AVATAR_CATEGORY'	=> 'Nėra',
	'NO_AUTH_DELETE_MESSAGE'	=> 'Jums neleidžiama ištrinti asmeninių žinučių.',
	'NO_AUTH_EDIT_MESSAGE'	=> 'Jums neleidžiama redaguoti asmeninių žinučių.',
	'NO_AUTH_FORWARD_MESSAGE'	=> 'Jums neleidžiama persiuntinėti asmeninių žinučių.',
	'NO_AUTH_GROUP_MESSAGE'	=> 'Jums neleidžiama siųsti asmeninių žinučių grupėms.',
	'NO_AUTH_PASSWORD_REMINDER'	=> 'Jums neleidžiama gauti naujo slaptažodžio.',
	'NO_AUTH_READ_HOLD_MESSAGE'	=> 'Jums neleidžiama skaityti asmeninių žinučių, kurios stovi eilėje.',
	'NO_AUTH_READ_MESSAGE'	=> 'Jums neleidžiama skaityti asmeninių žinučių.',
	'NO_AUTH_READ_REMOVED_MESSAGE'	=> 'Jūs negalite perskaityti šios žinutės, nes jos autorius ją ištrynė.',
	'NO_AUTH_SEND_MESSAGE'	=> 'Jums neleidžiama siųsti asmeninių žinučių.',
	'NO_AUTH_SIGNATURE'	=> 'Jums neleidžiama turėti parašo.',
	'NO_BCC_RECIPIENT'	=> 'Nėra',
	'NO_BOOKMARKS'	=> 'Žymių sąrašas tuščias.',
	'NO_BOOKMARKS_SELECTED'	=> 'Jūs nepasirinkote nei vienos žymės.',
	'NO_EDIT_READ_MESSAGE'	=> 'Asmeninės žinutės redaguoti nebegalima, nes ji jau buvo perskaityta.',
	'NO_EMAIL_USER'	=> 'Įrašyto el. pašto adreso ir/arba vartotojo vardo nėra.',
	'NO_FOES'	=> 'Priešų sąrašas tuščias',
	'NO_FRIENDS'	=> 'Draugų sąrašas tuščias',
	'NO_FRIENDS_OFFLINE'	=> 'Atsijungusių draugų nėra',
	'NO_FRIENDS_ONLINE'	=> 'Prisijungusių draugų nėra',
	'NO_GROUP_SELECTED'	=> 'Nenurodyta grupė.',
	'NO_IMPORTANT_NEWS'	=> 'Labai svarbių pranešimų nėra.',
	'NO_MESSAGE'	=> 'Nurodytos asmeninės žinutės nėra.',
	'NO_NEW_FOLDER_NAME'	=> 'Jūs turite įrašyti naujo katalogo pavadinimą.',
	'NO_NEWER_PM'	=> 'Naujesnių žinučių nėra.',
	'NO_OLDER_PM'	=> 'Senesnių žinučių nėra.',
	'NO_PASSWORD_SUPPLIED'	=> 'Jūs negalite prisijungti be slaptažodžio.',
	'NO_RECIPIENT'	=> 'Nenurodytas gavėjas.',
	'NO_RULES_DEFINED'	=> 'Taisyklių nėra.',
	'NO_SAVED_DRAFTS'	=> 'Išsaugotų juodraščių nėra.',
	'NO_TO_RECIPIENT'	=> 'Nėra',
	'NO_WATCHED_FORUMS'	=> 'Jūs neužsiprenumeravę jokių forumų.',
	'NO_WATCHED_SELECTED'	=> 'Jūs nepasirinkote jokių užprenumeruotų temų ar forumų.',
	'NO_WATCHED_TOPICS'	=> 'Jūs neužsiprenumeravę jokių temų.',
	'PASS_TYPE_ALPHA_EXPLAIN'	=> 'Slaptažodis turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti didžiųjų raidžių, mažųjų raidžių bei skaičių.',
	'PASS_TYPE_ANY_EXPLAIN'	=> 'Slaptažodis turi būti nuo %1$d iki %2$d simbolių ilgio.',
	'PASS_TYPE_CASE_EXPLAIN'	=> 'Slaptažodis turi būti nuo %1$d iki %2$d simbolių ilgio ir jame turi būti didžiųjų bei mažųjų raidžių.',
	'PASS_TYPE_SYMBOL_EXPLAIN'	=> 'Slaptažodis turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti didžiųjų raidžių, mažųjų raidžių, skaičių bei specialiųjų simbolių.',
	'PASSWORD'	=> 'Slaptažodis',
	'PASSWORD_ACTIVATED'	=> 'Jūsų naujas slaptažodis aktyvuotas.',
	'PASSWORD_UPDATED'	=> 'Naujas slaptažodis išsiųstas jūsų el. pašto adresu.',
	'PERMISSIONS_RESTORED'	=> 'Pirminės teisės sėkmingai sugrąžintos.',
	'PERMISSIONS_TRANSFERRED'	=> 'Jūs perėmėte vartotojo <strong>%s</strong> teises. Dabar galite naršyti diskusijose su jo teisėmis.<br />Įsidėmėkite, kad administratoriaus teisės nebuvo perimtos. Savo teises galite susigrąžinti bet kuriuo metu.',
	'PM_DISABLED'	=> 'Asmeninės žinutės šioje diskusijų lentoje yra išjungtos.',
	'PM_FROM'	=> 'Nuo',
	'PM_FROM_REMOVED_AUTHOR'	=> 'Ši žinutė gauta nuo vartotojo, kuris nebėra registruotas.',
	'PM_ICON'	=> 'AŽ piktograma',
	'PM_INBOX'	=> 'Gautos',
	'PM_NO_USERS'	=> 'Nurodyti vartotojai neegzistuoja.',
	'PM_OUTBOX'	=> 'Siunčiamos',
	'PM_SENTBOX'	=> 'Išsiųstos',
	'PM_SUBJECT'	=> 'Žinutės tema',
	'PM_TO'	=> 'Kam',
	'PM_USERS_REMOVED_NO_PM'	=> 'Kai kurie vartotojai negali būti įtraukti į gavėjų sąrašą, kadangi jie išjungė asmeninių žinučių gavimą.',
	'POPUP_ON_PM'	=> 'Iššokantis langas gavus naują asmeninį pranešimą',
	'POST_EDIT_PM'	=> 'Redaguoti žinutę',
	'POST_FORWARD_PM'	=> 'Persiųsti žinutę',
	'POST_NEW_PM'	=> 'Nauja žinutė',
	'POST_PM_LOCKED'	=> 'Asmeninių žinučių siuntimas užrakintas.',
	'POST_PM_POST'	=> 'Cituoti pranešimą',
	'POST_QUOTE_PM'	=> 'Cituoti žinutę',
	'POST_REPLY_PM'	=> 'Atsakyti į žinutę',
	'PRINT_PM'	=> 'Spausdinti',
	'PREFERENCES_UPDATED'	=> 'Jūsų nustatymai pakeisti.',
	'PROFILE_INFO_NOTICE'	=> 'Atsiminkite, kad šiuos duomenis gali matyti kiti diskusijų dalyviai. Būkite atsargūs, kai įtraukiate bet kokias asmenines detales. Bet kuris laukelis pažymėtas * turi būti užpildytas.',
	'PROFILE_UPDATED'	=> 'Jūsų aprašymas pakeistas.',
	'RECIPIENT'	=> 'Gavėjas',
	'RECIPIENTS'	=> 'Gavėjai',
	'REGISTRATION'	=> 'Registracija',
	'RELEASE_MESSAGES'	=> '%sAtsisiųsti visas laukiančias žinutes%s… jeigu bus vietos, jos bus išrūšiuotos po atitinkamus katalogus.',
	'REMOVE_ADDRESS'	=> 'Ištrinti adresą',
	'REMOVE_SELECTED_BOOKMARKS'	=> 'Ištrinti pasirinktas žymes',
	'REMOVE_SELECTED_BOOKMARKS_CONFIRM'	=> 'Ar tikrai norite ištrinti visas pasirinktas žymes?',
	'REMOVE_BOOKMARK_MARKED'	=> 'Ištrinti pažymėtas žymes',
	'REMOVE_FOLDER'	=> 'Ištrinti katalogą',
	'REMOVE_FOLDER_CONFIRM'	=> 'Ar tikrai norite ištrinti šį katalogą?',
	'RENAME'	=> 'Pervadinti',
	'RENAME_FOLDER'	=> 'Pervadinti katalogą',
	'REPLIED_MESSAGE'	=> 'Atsakyta į žinutę',
	'REPLY_TO_ALL'	=> 'Atsakyti siuntėjui ir visiems adresatams.',
	'REPORT_PM'	=> 'Raportuoti apie šią asmeninę žinutę',
	'RESIGN_SELECTED'	=> 'Atsisakyti',
	'RETURN_FOLDER'	=> '%1$sGrįžti į ankstesnį katalogą%2$s',
	'RETURN_UCP'	=> '%sGrįžti į vartotojo valdymo pultą%s',
	'RULE_ADDED'	=> 'Taisyklė sėkmingai sukurta.',
	'RULE_ALREADY_DEFINED'	=> 'Tokia taisyklė jau egzistuoja.',
	'RULE_DELETED'	=> 'Taisyklė sėkmingai ištrinta.',
	'RULE_NOT_DEFINED'	=> 'Taisyklė aprašyta neteisingai.',
	'RULE_REMOVED_MESSAGE'	=> 'Asmeninė žinutė buvo ištrinta, nes atitiko vieną iš nustatytų taisyklių.',
	'RULE_REMOVED_MESSAGES'	=> '%d asmeninės žinutės buvo ištrintos, nes atitiko vieną iš nustatytų taisyklių.',
	'SAME_PASSWORD_ERROR'	=> 'Naujas slaptažodis, kurį įrašėte, yra toks pats, koks ir senas slaptažodis.',
	'SEARCH_YOUR_POSTS'	=> 'Rodyti jūsų pranešimus',
	'SEND_PASSWORD'	=> 'Slaptažodžio siuntimas',
	'SENT_AT'	=> 'Išsiųsta',
	'SHOW_EMAIL'	=> 'Vartotojai gali rašyti man el. paštu',
	'SIGNATURE_EXPLAIN'	=> 'Parašas yra trumpas teksto blokas, kuris bus pridedamas prie kiekvieno jūsų pranešimo. Jis turi būti ne ilgesnis kaip %d simbolių.',
	'SIGNATURE_PREVIEW'	=> 'Štai taip parašas atrodys po kiekvienu pranešimu',
	'SIGNATURE_TOO_LONG'	=> 'Jūsų parašas per ilgas.',
	'SORT'	=> 'Rūšiuoti',
	'SORT_COMMENT'	=> 'Failo aprašymą',
	'SORT_DOWNLOADS'	=> 'Atsisiuntimų skaičių',
	'SORT_EXTENSION'	=> 'Galūnę',
	'SORT_FILENAME'	=> 'Failo pavadinimą',
	'SORT_POST_TIME'	=> 'Pranešimą datą',
	'SORT_SIZE'	=> 'Failo dydį',
	'TIMEZONE'	=> 'Laiko juosta',
	'TO'	=> 'Kam',
	'TOO_MANY_RECIPIENTS'	=> 'Jūs bandėte išsiųsti asmeninę žinutę per dideliam gavėjų skaičiui.',
	'TOO_MANY_REGISTERS'	=> 'Šios sesijos metu daugiau bandyti registruotis negalite. Pabandykite vėliau.',
	'UCP'	=> 'Vartotojo valdymo pultas',
	'UCP_ACTIVATE'	=> 'Aktyvuoti vartotojo vardą',
	'UCP_ADMIN_ACTIVATE'	=> 'Įsidėmėkite, kad prieš aktyvuojant vartotojo vardą turėsite įrašyti tikrą el. pašto adresą. Kai administratorius peržiūrės ir patvirtins jūsų vartotojo vardą, el. pašto adresu, kurį nurodėte, gausite laišką.',
	'UCP_AIM'	=> 'AOL Instant Messenger',
	'UCP_ATTACHMENTS'	=> 'Prikabinti failai',
	'UCP_COPPA_BEFORE'	=> 'Prieš %s',
	'UCP_COPPA_ON_AFTER'	=> 'Lygiai arba po %s',
	'UCP_EMAIL_ACTIVATE'	=> 'Įsidėmėkite, kad prieš aktyvuojant vartotojo vardą turėsite įrašyti tikrą el. pašto adresą. Tuo adresu, gausite el. laišką, kuriame rasite vartotojo vardo aktyvavimo nuorodą.',
	'UCP_ICQ'	=> 'ICQ numeris',
	'UCP_JABBER'	=> 'Jabber adresas',
	'UCP_MAIN'	=> 'Santrauka',
	'UCP_MAIN_ATTACHMENTS'	=> 'Valdyti prikabintus failus',
	'UCP_MAIN_BOOKMARKS'	=> 'Valdyti žymes',
	'UCP_MAIN_DRAFTS'	=> 'Valdyti juodraščius',
	'UCP_MAIN_FRONT'	=> 'Pirmas puslapis',
	'UCP_MAIN_SUBSCRIBED'	=> 'Valdyti prenumeratą',
	'UCP_MSNM'	=> 'WL/MSN Messenger',
	'UCP_NO_ATTACHMENTS'	=> 'Jūs neprikabinote nei vieno failo.',
	'UCP_PREFS'	=> 'Diskusijų lentos nustatymai',
	'UCP_PREFS_PERSONAL'	=> 'Keisti globalius nustatymus',
	'UCP_PREFS_POST'	=> 'Keisti rašymo nustatymus',
	'UCP_PREFS_VIEW'	=> 'Keisti rodymo nustatymus',
	'UCP_PM'	=> 'Asmeninės žinutės',
	'UCP_PM_COMPOSE'	=> 'Nauja žinutė',
	'UCP_PM_DRAFTS'	=> 'Valdyti AŽ juodraščius',
	'UCP_PM_OPTIONS'	=> 'Taisyklės, katalogai ir nustatymai',
	'UCP_PM_POPUP'	=> 'Asmeninės žinutės',
	'UCP_PM_POPUP_TITLE'	=> 'Asmeninių žinučių langas',
	'UCP_PM_UNREAD'	=> 'Neperskaitytos žinutės',
	'UCP_PM_VIEW'	=> 'Peržiūrėti žinutes',
	'UCP_PROFILE'	=> 'Aprašymas',
	'UCP_PROFILE_AVATAR'	=> 'Keisti avatarą',
	'UCP_PROFILE_PROFILE_INFO'	=> 'Keisti aprašymą',
	'UCP_PROFILE_REG_DETAILS'	=> 'Keisti vartotojo nustatymus',
	'UCP_PROFILE_SIGNATURE'	=> 'Keisti parašą',
	'UCP_USERGROUPS'	=> 'Vartotojų grupės',
	'UCP_USERGROUPS_MEMBER'	=> 'Keisti narystę',
	'UCP_USERGROUPS_MANAGE'	=> 'Valdyti grupes',
	'UCP_REGISTER_DISABLE'	=> 'Šiuo metu užsiregistruoti negalima.',
	'UCP_REMIND'	=> 'Slaptažodžio siuntimas',
	'UCP_RESEND'	=> 'Aktyvavimo nuorodos siuntimas',
	'UCP_WELCOME'	=> 'Sveiki atvykę į vartotojo valdymo pultą. Čia jūs galite stebėti, peržiūrėti ir keisti savo aprašymą, nustatymus, prenumeruojamus forumus bei temas. Taip pat galite siųsti žinutes kitiems vartotojams (jeigu turite tam reikiamas teises). Prieš tęsdami perskaitykite naujus svarbius pranešimus.',
	'UCP_YIM'	=> 'Yahoo Messenger',
	'UCP_ZEBRA'	=> 'Draugai ir priešai',
	'UCP_ZEBRA_FOES'	=> 'Valdyti priešus',
	'UCP_ZEBRA_FRIENDS'	=> 'Valdyti draugus',
	'UNDISCLOSED_RECIPIENT'	=> 'Gavėjas nerodomas',
	'UNKNOWN_FOLDER'	=> 'Nežinomas katalogas',
	'UNWATCH_MARKED'	=> 'Nebestebėti pažymėtų',
	'UPLOAD_AVATAR_FILE'	=> 'Nusiųsti iš savo kompiuterio',
	'UPLOAD_AVATAR_URL'	=> 'Nusiųsti iš URL adreso',
	'UPLOAD_AVATAR_URL_EXPLAIN'	=> 'Įveskite URL adresą, kur yra jūsų avataro paveikslėlis. Paveikslėlis bus nukopijuotas į šį tinklapį.',
	'USERNAME_ALPHA_ONLY_EXPLAIN'	=> 'Vartotojo vardas turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti tik raidės ir skaičiai.',
	'USERNAME_ALPHA_SPACERS_EXPLAIN'	=> 'Vartotojo vardas turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti tik raidės, skaičiai, tarpai arba simboliai -+_[].',
	'USERNAME_ASCII_EXPLAIN'	=> 'Vartotojo vardas turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti tik ASCII simboliai.',
	'USERNAME_LETTER_NUM_EXPLAIN'	=> 'Vartotojo vardas turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti tik raidės ir skaičiai.',
	'USERNAME_LETTER_NUM_SPACERS_EXPLAIN'	=> 'Vartotojo vardas turi būti nuo %1$d iki %2$d simbolių ilgio. Jame turi būti tik raidės, skaičiai, tarpai arba simboliai -+_[].',
	'USERNAME_CHARS_ANY_EXPLAIN'	=> 'Vartotojo vardas turi būti nuo %1$d iki %2$d simbolių ilgio.',
	'USERNAME_TAKEN_USERNAME'	=> 'Toks vartotojo vardas jau yra, pasirinkite kitą.',
	'USERNAME_DISALLOWED_USERNAME'	=> 'Vartotojo vardas, kurį įrašėte, yra uždraustas arba yra iš uždraustų žodžių. Pasirinkite kitą.',
	'USER_NOT_FOUND_OR_INACTIVE'	=> 'Vartotojų vardai, kuriuos nurodėte, neegzistuoja arba nėra aktyvuoti.',
	'VIEW_AVATARS'	=> 'Rodyti avatarus',
	'VIEW_EDIT'	=> 'Rodyti/Redaguoti',
	'VIEW_FLASH'	=> 'Rodyti Flash animaciją',
	'VIEW_IMAGES'	=> 'Rodyti paveikslėlius pranešimuose',
	'VIEW_NEXT_HISTORY'	=> 'Kita AŽ istorijoje',
	'VIEW_NEXT_PM'	=> 'Kita AŽ',
	'VIEW_PM'	=> 'Rodyti žinutę',
	'VIEW_PM_INFO'	=> 'Žinutės turinys',
	'VIEW_PM_MESSAGE'	=> '1 žinutė',
	'VIEW_PM_MESSAGES'	=> '%d žinutės(čių)',
	'VIEW_PREVIOUS_HISTORY'	=> 'Ankstesnė AŽ istorijoje',
	'VIEW_PREVIOUS_PM'	=> 'Ankstesnė AŽ',
	'VIEW_SIGS'	=> 'Rodyti parašus',
	'VIEW_SMILIES'	=> 'Rodyti šypsenėles',
	'VIEW_TOPICS_DAYS'	=> 'Rodyti paskutines temas',
	'VIEW_TOPICS_DIR'	=> 'Temų rūšiavimo kryptis',
	'VIEW_TOPICS_KEY'	=> 'Rūšiuoti temas pagal',
	'VIEW_POSTS_DAYS'	=> 'Rodyti paskutinius pranešimus',
	'VIEW_POSTS_DIR'	=> 'Pranešimų rūšiavimo kryptis',
	'VIEW_POSTS_KEY'	=> 'Rūšiuoti pranešimus pagal',
	'WATCHED_EXPLAIN'	=> 'Apačioje matote forumų ir temų sąrašą kuriuos prenumeruojate. Apie naujus pranešimus jose jums pranešama. Norėdami nutraukti prenumeratą, pažymėkite forumą arba temą ir paspauskite <em>Nebestebėti pažymėtų</em> mygtuką.',
	'WATCHED_FORUMS'	=> 'Stebimi forumai',
	'WATCHED_TOPICS'	=> 'Stebimos temos',
	'WRONG_ACTIVATION'	=> 'Aktyvavimo raktas, kurį nurodėte, nesutampa su raktu esančiu duomenų bazėje.',
	'YOUR_DETAILS'	=> 'Jūsų veikla',
	'YOUR_FOES'	=> 'Jūsų priešai',
	'YOUR_FOES_EXPLAIN'	=> 'Norėdami ištrinti vartotojo vardą, pažymėkite jį ir paspauskite mygtuką apačioje.',
	'YOUR_FRIENDS'	=> 'Jūsų draugai',
	'YOUR_FRIENDS_EXPLAIN'	=> 'Norėdami ištrinti vartotojo vardą, pažymėkite jį ir paspauskite mygtuką apačioje.',
	'YOUR_WARNINGS'	=> 'Jūsų įspėjimo lygis',

	'PM_ACTION'	=> array(
		'PLACE_INTO_FOLDER'	=> 'Perkelti į katalogą',
		'MARK_AS_READ'	=> 'Pažymėti kaip skaitytą',
		'MARK_AS_IMPORTANT'	=> 'Pažymėti žinutę',
		'DELETE_MESSAGE'	=> 'Ištrinti žinutę',
	),


	'PM_CHECK'	=> array(
		'SUBJECT'	=> 'Tema',
		'SENDER'	=> 'Siuntėjas',
		'MESSAGE'	=> 'Žinutė',
		'STATUS'	=> 'Žinutė būsena',
		'TO'	=> 'Kam',
	),


	'PM_RULE'	=> array(
		'IS_LIKE'	=> 'yra kaip',
		'IS_NOT_LIKE'	=> 'nėra kaip',
		'IS'	=> 'yra',
		'IS_NOT'	=> 'nėra',
		'BEGINS_WITH'	=> 'prasideda',
		'ENDS_WITH'	=> 'baigiasi',
		'IS_FRIEND'	=> 'yra draugas',
		'IS_FOE'	=> 'yra priešas',
		'IS_USER'	=> 'yra vartotojas',
		'IS_GROUP'	=> 'yra grupėje',
		'ANSWERED'	=> 'atsakyta',
		'FORWARDED'	=> 'persiųsta',
		'TO_GROUP'	=> 'mano pagrindinėje grupėje',
		'TO_ME'	=> 'man',
	),

	'GROUPS_EXPLAIN'	=> 'Vartotojų grupės įgalina diskusijų administratorius patogiau valdyti vartotojus. Standartiškai, jūs būsite priskirtas kuriai nors vienai grupei. Tai bus jūsų pagrindinė grupė. Ši grupė apsprendžia, kaip jūs būsite matomas kitiems vartotojams, pvz.: jūsų vartotojo vardo spalva, avataras, rangas ir t.t. Jeigu administratorius leidžia, jūs galite pasikeisti savo pagrindinę grupę. Jūs taip pat galite būti paskirtas arba pats tapti kitų grupių nariu. Kai kurios grupės gali jums suteikti papildomų teisių ir galimybių.',
	'GROUP_LEADER'	=> 'Lyderis',
	'GROUP_MEMBER'	=> 'Narys',
	'GROUP_PENDING'	=> 'Nepatvirtintas narys',
	'GROUP_NONMEMBER'	=> 'Ne narys',
	'GROUP_DETAILS'	=> 'Grupės aprašymas',
	'NO_LEADER'	=> 'Jūs nesate jokios grupės lyderis',
	'NO_MEMBER'	=> 'Jūs nesate jokios grupės narys',
	'NO_PENDING'	=> 'Grupių, kuriose jūsų narystė dar nepatvirtinta, nėra',
	'NO_NONMEMBER'	=> 'Grupių, kuriose nesate narys, nėra',
));

?>